@@ -21,4 +21,15 @@ pub(crate) fn is_ignored_word(word: &str, ignored_words: &Value) -> bool {
 pub(crate) fn get_random_index(vec: &Vec<Value>) -> usize {
     let len = vec.len();
     rand::thread_rng().gen_range(0..len)
+}
+
+#[cfg(feature = "interlude")]
+pub(crate) fn is_one_percent_chance() -> bool {
+    let random = rand::thread_rng().gen_range(0..100);
+
+    if random == 1 {
+        return true;
+    }
+
+    false
 }
\ No newline at end of file
